@@ -1,4 +1,9 @@
-from jarvis.core.atoms import Atoms, VacuumPadding, get_supercell_dims
+from jarvis.core.atoms import (
+    Atoms,
+    VacuumPadding,
+    get_supercell_dims,
+    build_xanes_poscar,
+)
 import os
 from jarvis.db.figshare import get_jid_data, data
 import tarfile
@@ -87,6 +92,7 @@ def test_basic_atoms():
     elements = ["Si", "Si"]
     Si = Atoms(lattice_mat=box, coords=coords, elements=elements)
     dim = get_supercell_dims(Si)
+    build_xanes_poscar(atoms=Si, filename_with_prefix=True)
     assert dim == [3, 3, 3]
     polar = Si.check_polar
     Si.props = ["a", "a"]
